Struct trust_dns_client::client::AsyncClient
source · pub struct AsyncClient { /* private fields */ }Expand description
A DNS Client implemented over futures-rs.
This Client is generic and capable of wrapping UDP, TCP, and other underlying DNS protocol implementations.
Implementations
sourceimpl AsyncClient
impl AsyncClient
sourcepub async fn new<F, S>(
stream: F,
stream_handle: BufDnsStreamHandle,
signer: Option<Arc<Signer>>
) -> Result<(Self, DnsExchangeBackground<DnsMultiplexer<S, Signer>, TokioTime>), ProtoError>where
F: Future<Output = Result<S, ProtoError>> + Send + Unpin + 'static,
S: DnsClientStream + 'static + Unpin,
pub async fn new<F, S>( stream: F, stream_handle: BufDnsStreamHandle, signer: Option<Arc<Signer>> ) -> Result<(Self, DnsExchangeBackground<DnsMultiplexer<S, Signer>, TokioTime>), ProtoError>where F: Future<Output = Result<S, ProtoError>> + Send + Unpin + 'static, S: DnsClientStream + 'static + Unpin,
Spawns a new AsyncClient Stream. This uses a default timeout of 5 seconds for all requests.
Arguments
stream- A stream of bytes that can be used to send/receive DNS messages (see TcpClientStream or UdpClientStream)stream_handle- The handle for thestreamon which bytes can be sent/received.signer- An optional signer for requests, needed for Updates with Sig0, otherwise not needed
sourcepub async fn with_timeout<F, S>(
stream: F,
stream_handle: BufDnsStreamHandle,
timeout_duration: Duration,
signer: Option<Arc<Signer>>
) -> Result<(Self, DnsExchangeBackground<DnsMultiplexer<S, Signer>, TokioTime>), ProtoError>where
F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
S: DnsClientStream + 'static + Unpin,
pub async fn with_timeout<F, S>( stream: F, stream_handle: BufDnsStreamHandle, timeout_duration: Duration, signer: Option<Arc<Signer>> ) -> Result<(Self, DnsExchangeBackground<DnsMultiplexer<S, Signer>, TokioTime>), ProtoError>where F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin, S: DnsClientStream + 'static + Unpin,
Spawns a new AsyncClient Stream.
Arguments
stream- A stream of bytes that can be used to send/receive DNS messages (see TcpClientStream or UdpClientStream)timeout_duration- All requests may fail due to lack of response, this is the time to wait for a response before canceling the request.stream_handle- The handle for thestreamon which bytes can be sent/received.signer- An optional signer for requests, needed for Updates with Sig0, otherwise not needed
sourcepub async fn connect<F, S>(
connect_future: F
) -> Result<(Self, DnsExchangeBackground<S, TokioTime>), ProtoError>where
S: DnsRequestSender,
F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
pub async fn connect<F, S>( connect_future: F ) -> Result<(Self, DnsExchangeBackground<S, TokioTime>), ProtoError>where S: DnsRequestSender, F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
Returns a future, which itself wraps a future which is awaiting connection.
The connect_future should be lazy.
Returns
This returns a tuple of Self a handle to send dns messages and an optional background. The background task must be run on an executor before handle is used, if it is Some. If it is None, then another thread has already run the background.
sourcepub fn enable_edns(&mut self)
pub fn enable_edns(&mut self)
(Re-)enable usage of EDNS for outgoing messages
sourcepub fn disable_edns(&mut self)
pub fn disable_edns(&mut self)
Disable usage of EDNS for outgoing messages