pub struct AsyncSecureClientBuilder<F, S>where
F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
S: DnsRequestSender + 'static,{ /* private fields */ }Available on crate feature
dnssec only.Expand description
A builder to allow a custom trust to be used for validating all signed records
Implementations
Sourceimpl<F, S> AsyncSecureClientBuilder<F, S>where
F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
S: DnsRequestSender + 'static,
impl<F, S> AsyncSecureClientBuilder<F, S>where
F: Future<Output = Result<S, ProtoError>> + 'static + Send + Unpin,
S: DnsRequestSender + 'static,
Sourcepub fn trust_anchor(self, trust_anchor: TrustAnchor) -> Self
pub fn trust_anchor(self, trust_anchor: TrustAnchor) -> Self
This variant allows for the trust_anchor to be replaced
Arguments
trust_anchor- the set of trusted DNSKEY public_keys, by default this only contains the root public_key.
Sourcepub async fn build(
self,
) -> Result<(AsyncDnssecClient, DnsExchangeBackground<S, TokioTime>), ProtoError>
pub async fn build( self, ) -> Result<(AsyncDnssecClient, DnsExchangeBackground<S, TokioTime>), ProtoError>
Construct the new client